#ifndef DEFINE_ISLIB_BINARY_COMPARE_HPP

#define DEFINE_ISLIB_BINARY_COMPARE_HPP

//
// Inclusion of library header file
//
#include <boost/filesystem/path.hpp>

namespace islib
  {
    //
    // Declaration of function
    //
    int binary_compare ( boost::filesystem::path const &, boost::filesystem::path const & );
  }

#endif // DEFINE_ISLIB_BINARY_COMPARE_HPP

//
// End of file
//
